@@ -9,7 +9,7 @@
 import json
 import logging
 from asyncio import Semaphore
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from typing import Mapping, Optional, Any
 
 import yarl
@@ -54,7 +54,7 @@ class HttpServerConnector(AsyncOnStop):
     @dataclass
     class Context:
         session: ClientSession
-        instance_id: str = ""  # empty string - backward compatibility
+        instance_id: str = field(default="", kw_only=True)
 
     def __init__(self, config: Config, context: Context):
         logger.info(f"initiating {type(self).__name__}, {config.url}")
